Kafka Tools
===========

This repository is a collection of tools for working with
`Apache Kafka <http://kafka.apache.org>`_.

The Site Reliability team for Kafka at LinkedIn has built these over time in
order to make managing Kafka a little bit easier. Our intention is to add to
this repository as more tools are developed.

We welcome additions and modifications that make managing Kafka better for all!

.. image:: https://readthedocs.org/projects/kafka-tools/badge/?version=latest
   :target: http://kafka-tools.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. image:: https://travis-ci.org/linkedin/kafka-tools.svg
   :target: https://travis-ci.org/linkedin/kafka-tools
   :alt: Build Status
.. image:: https://coveralls.io/repos/github/linkedin/kafka-tools/badge.svg?branch=master
   :target: https://coveralls.io/github/linkedin/kafka-tools?branch=master
   :alt: Coveralls Test Coverage
.. image:: https://codeclimate.com/github/linkedin/kafka-tools/badges/issue_count.svg
   :target: https://codeclimate.com/github/linkedin/kafka-tools
   :alt: Issue Count
.. image:: https://requires.io/github/linkedin/kafka-tools/requirements.svg?branch=master
   :target: https://requires.io/github/linkedin/kafka-tools/requirements/?branch=master
   :alt: Requirements Status

Quick Start
-----------

1) First, download and install the Kafka admin utilities from: http://kafka.apache.org/downloads.html
2) Then, install kafka-tools using the following command: :code:`pip install kafka-tools`

Additional documentation may be found at `https://kafka-tools.readthedocs.io <https://kafka-tools.readthedocs.io/en/latest/>`_.

Contributing
------------

Please see the `contribution guidelines <https://kafka-tools.readthedocs.io/en/latest/contributing.html>`_.

Other Projects
--------------

In addition to these tools, LinkedIn has also open-sourced
`Burrow <https://github.com/linkedin/Burrow>`_, a robust system for monitoring
Kafka consumer clients.

License
-------

Copyright 2016 LinkedIn Corp.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at:

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
